@@ -7,12 +7,39 @@ from .core.exc import BioNetGenError
 from .core.main import runCLI
 from .core.main import plotDAT
 from .core.main import printInfo
+from .core.main import visualizeModel
 from .core.notebook import BNGNotebook
 
 # pull defaults defined in core/defaults
 CONFIG = bng.defaults.config
 VERSION_BANNER = bng.defaults.banner
 
+# require version argparse action
+import argparse, sys
+from pkg_resources import packaging
+
+
+class requireAction(argparse.Action):
+    def __init__(self, option_strings, dest, nargs=None, **kwargs):
+        if nargs is not None:
+            raise ValueError("nargs not allowed")
+        super().__init__(option_strings, dest, **kwargs)
+
+    def __call__(self, parser, namespace, values, option_string=None):
+        setattr(namespace, self.dest, values)
+        if values is not None:
+            req_version = packaging.version.parse(values)
+            cver = bng.core.version.get_version()
+            cur_version = packaging.version.parse(cver)
+            # if we don't meet requirement, warn user
+            sys.tracebacklimit = 0
+            if not (cur_version >= req_version):
+                raise RuntimeError(
+                    f"Version {values} is required but current version is {cver}. \n"
+                    + "Try running `pip install bionetgen --upgrade`"
+                )
+        # return super().__call__(parser, namespace, values, option_string=option_string)
+
 
 class BNGBase(cement.Controller):
     """
@@ -32,6 +59,8 @@ class BNGBase(cement.Controller):
         plots a gdat/cdat/scan file given by -i into file supplied by -o
     info
         provides version and path information about the BNG installation and dependencies
+    visualize
+        provides various visualization options for BNG models
     """
 
     class Meta:
@@ -39,17 +68,13 @@ class BNGBase(cement.Controller):
         description = "A simple CLI to bionetgen <https://bionetgen.org>. Note that you need Perl installed."
         help = "bionetgen"
         arguments = [
-            # TODO figure out a good solution for when bngpath is set from config file AND CLI
-            # until then we'll disable the CLI argument
-            # (['-bp','--bngpath'],dict(type=str,
-            #                           default=CONFIG['bionetgen']['bngpath'],
-            #                           help="Optional path to BioNetGen folder you want the CLI to use")),
             # TODO: Auto-load in BioNetGen version here
             (["-v", "--version"], dict(action="version", version=VERSION_BANNER)),
             # (['-s','--sedml'],dict(type=str,
             #                        default=CONFIG['bionetgen']['bngpath'],
             #                        help="Optional path to SED-ML file, if available the simulation \
             #                              protocol described in SED-ML will be ran")),
+            (["-req", "--require"], dict(action=requireAction, type=str, default=None)),
         ]
 
     # This overwrites the default behavior and runs the CLI object from core/main
@@ -83,6 +108,16 @@ class BNGBase(cement.Controller):
                     "dest": "log_file",
                 },
             ),
+            (
+                ["--traceback-depth"],
+                {
+                    "help": "Sets the traceback depth for python. "
+                    + "Defaults to 0 to avoid long tracebacks after a failed BNG2.pl call",
+                    "default": 0,
+                    "type": int,
+                    "dest": "traceback_depth",
+                },
+            ),
         ],
     )
     def run(self):
@@ -281,7 +316,11 @@ class BNGBase(cement.Controller):
         arguments=[
             (
                 ["-d", "--detail"],
-                {"help": "___", "default": False, "action": "store_true"},
+                {
+                    "help": "Adds more detail to the information printed.",
+                    "default": False,
+                    "action": "store_true",
+                },
             ),
         ],
     )
@@ -295,6 +334,52 @@ class BNGBase(cement.Controller):
         args = self.app.pargs
         printInfo(self.app.config, args)
 
+    @cement.ex(
+        help="Provides a simple way to get various visualizations of the model.",
+        arguments=[
+            (
+                ["-i", "--input"],
+                {
+                    "help": "Path to BNGL model to visualize",
+                    "default": None,
+                    "type": str,
+                    "required": True,
+                },
+            ),
+            (
+                ["-o", "--output"],
+                {
+                    "help": "(optional) Output folder, defaults to current folder",
+                    "default": None,
+                    "type": str,
+                },
+            ),
+            (
+                ["-t", "--type"],
+                {
+                    "help": "(optional) Type of visualization requested. Valid options are: "
+                    + "'ruleviz_pattern','ruleviz_operation', 'contactmap' and 'regulatory'."
+                    + " Defaults to 'contactmap'.",
+                    "default": "",
+                    "type": str,
+                },
+            ),
+        ],
+    )
+    def visualize(self):
+        """
+        Subcommand to generate visualizations. Currently only supports visualize
+        action from BioNetGen.
+
+        Types of visualizations and their options
+        - Rule pattern visualization: Visualization of each rule as a bipartite graph
+        - Rule operation visualization: Visualization of each rule showing explicit graph operations
+        - Contact map: Visualize the contact map of the model
+        - Regulatory graph: Visualize the regulatory graph of the model
+        """
+        args = self.app.pargs
+        visualizeModel(self.app.config, args)
+
 
 class BioNetGen(cement.App):
     """
